@@ -1,10 +1,10 @@
-__version__ = "0.2"
+__version__ = "0.2.1"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
 __git_branch__ = '(Not currently on any branch)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '9aa9d04cb52df7c4e28b6efc3b24c52d8368da3d'
-__git_head_subject__ = 'Finished release v0.2.'
+__git_head_hash__ = '2dd643602c97ab6b1fbff08ab21079cf68226876'
+__git_head_subject__ = 'Finished release v0.2.1.'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
